@@ -12,9 +12,7 @@ fn main() {
     let yaml = load_yaml!("arg.yaml");
     let args = App::from(yaml).version(crate_version!()).get_matches();
     // convert arguments to rust variables
-    let city = args
-        .value_of("id")
-        .unwrap_or(args.value_of("city").unwrap());
+    let location = args.value_of("location").unwrap();
     let apikey = args.value_of("apikey").unwrap_or("");
     let units = args.value_of("units").unwrap();
     let format = args.value_of("format").unwrap();
@@ -31,7 +29,7 @@ fn main() {
         .parse::<u64>()
         .unwrap_or(10);
     // start our observatory via OWM
-    let receiver = &openweathermap::init(city, units, lang, apikey, poll);
+    let receiver = &openweathermap::init(location, units, lang, apikey, poll);
     i3status_ext::begin();
     // remeber newest weather update and begin with offline message
     let mut current = String::new();
@@ -107,7 +105,7 @@ fn make_string(format: &str, current: &openweathermap::CurrentWeather, units: &s
         .replace(
             "{rain.1h}",
             &match &current.rain {
-                Some(r) => r.h1.to_string(),
+                Some(r) => r.h1.unwrap_or(0.0).to_string(),
                 None => "-".to_string(),
             }
             .to_string(),
@@ -115,21 +113,21 @@ fn make_string(format: &str, current: &openweathermap::CurrentWeather, units: &s
         .replace(
             "{rain.3h}",
             &match &current.rain {
-                Some(r) => r.h3.to_string(),
+                Some(r) => r.h3.unwrap_or(0.0).to_string(),
                 None => "-".to_string(),
             },
         )
         .replace(
             "{snow.1h}",
             &match &current.snow {
-                Some(r) => r.h1.to_string(),
+                Some(r) => r.h1.unwrap_or(0.0).to_string(),
                 None => "-".to_string(),
             },
         )
         .replace(
             "{snow.3h}",
             &match &current.snow {
-                Some(r) => r.h3.to_string(),
+                Some(r) => r.h3.unwrap_or(0.0).to_string(),
                 None => "-".to_string(),
             },
         )
